"""Pydantic-схемы ответов WB API."""

from wbsdk.schemas.analytics import (
    NmReportCreateResponse,
    NmReportItem,
    NmReportRetryResponse,
    NmReportsListResponse,
    SalesFunnelGroupedResponse,
    SalesFunnelHistoryResponse,
    SalesFunnelProductsResponse,
    SearchReportResponse,
    StocksGroupsResponse,
    StocksProductsResponse,
)
from wbsdk.schemas.common import ErrorDetail, PaginationNext
from wbsdk.schemas.content import (
    BarcodesResponse,
    BrandsResponse,
    CardsLimitsResponse,
    CardsListResponse,
    ContentMutationResponse,
    DirectoryItem,
    DirectoryListResponse,
    ParentCategoriesResponse,
    Subject,
    SubjectCharacteristicsResponse,
    SubjectsResponse,
    Tag,
    TagMutationResponse,
    TagsResponse,
    TnvedResponse,
)
from wbsdk.schemas.marketplace import (
    BarcodeResponse,
    CrossBorderStickersResponse,
    Order,
    OrderMetaResponse,
    OrdersClientInfoResponse,
    OrdersNewResponse,
    OrdersResponse,
    OrdersStatusResponse,
    Pass,
    PassCreateResponse,
    PassOffice,
    ReshipmentResponse,
    StickersResponse,
    Supply,
    SupplyBoxesResponse,
    SupplyCreateResponse,
    SupplyOrderIdsResponse,
    SuppliesResponse,
    TrbxIdsResponse,
    TrbxStickersResponse,
)
from wbsdk.schemas.prices import (
    GoodsSizesResponse,
    GoodsWithPricesResponse,
    PriceUploadResponse,
    QuarantineGoodsResponse,
    UploadDetailsResponse,
    UploadStateResponse,
)
from wbsdk.schemas.warehouses import (
    Office,
    StocksResponse,
    StoreContact,
    Warehouse,
    WarehouseCreateResponse,
)

__all__ = [
    # Analytics
    "NmReportCreateResponse",
    "NmReportItem",
    "NmReportRetryResponse",
    "NmReportsListResponse",
    "SalesFunnelGroupedResponse",
    "SalesFunnelHistoryResponse",
    "SalesFunnelProductsResponse",
    "SearchReportResponse",
    "StocksGroupsResponse",
    "StocksProductsResponse",
    # Common
    "ErrorDetail",
    "PaginationNext",
    # Content
    "BarcodesResponse",
    "BrandsResponse",
    "CardsLimitsResponse",
    "CardsListResponse",
    "ContentMutationResponse",
    "DirectoryItem",
    "DirectoryListResponse",
    "ParentCategoriesResponse",
    "Subject",
    "SubjectCharacteristicsResponse",
    "SubjectsResponse",
    "Tag",
    "TagMutationResponse",
    "TagsResponse",
    "TnvedResponse",
    # Marketplace
    "BarcodeResponse",
    "CrossBorderStickersResponse",
    "Order",
    "OrderMetaResponse",
    "OrdersClientInfoResponse",
    "OrdersNewResponse",
    "OrdersResponse",
    "OrdersStatusResponse",
    "Pass",
    "PassCreateResponse",
    "PassOffice",
    "ReshipmentResponse",
    "StickersResponse",
    "Supply",
    "SupplyBoxesResponse",
    "SupplyCreateResponse",
    "SupplyOrderIdsResponse",
    "SuppliesResponse",
    "TrbxIdsResponse",
    "TrbxStickersResponse",
    # Prices
    "GoodsSizesResponse",
    "GoodsWithPricesResponse",
    "PriceUploadResponse",
    "QuarantineGoodsResponse",
    "UploadDetailsResponse",
    "UploadStateResponse",
    # Warehouses
    "Office",
    "StocksResponse",
    "StoreContact",
    "Warehouse",
    "WarehouseCreateResponse",
]
